# 1 install

```
pip install pyxllib
```

more details: https://www.yuque.com/xlpr/pyxllib/install

# 2 document

document: https://www.yuque.com/xlpr/pyxllib.
Work hard to improve, welcome more assistant partners.

# 3 Acknowledge

This project uses PyCharm to develop.
Thanks to [JetBrains'](https://www.jetbrains.com/?from=pyxllib) support
of [free license for open sourse project development](http://pycharm.iswbm.com/zh_CN/latest/c01/c01_05.html).
